@@ -1,4 +1,4 @@
-# $Id: POE.pm 2151 2006-11-03 07:20:25Z rcaputo $
+# $Id: POE.pm 2165 2007-01-03 17:29:46Z rcaputo $
 # Copyrights and documentation are after __END__.
 
 package POE;
@@ -7,8 +7,8 @@ use strict;
 use Carp qw( croak );
 
 use vars qw($VERSION $REVISION);
-$VERSION = '0.9500'; # NOTE - Should be #.#### (four decimal places)
-$REVISION = do {my($r)=(q$Revision: 2151 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = '0.9917'; # NOTE - Should be #.#### (four decimal places)
+$REVISION = do {my($r)=(q$Revision: 2165 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 sub import {
   my $self = shift;
@@ -176,8 +176,9 @@ assume that something doesn't exist if it's not there.
 
 There are also some helper classes.  POE::Pipe is the base class for
 POE::Pipe::OneWay and POE::Pipe::TwoWay.  They are portable pipe
-creation functions, mainly for POE's test suite.  POE::Preprocessor is
-a macro language implemented as a source filter.
+creation functions, mainly for POE's test suite.  POE::Preprocessor, a
+macro language implemented as a source filter, has been split off into
+its own distribution: Filter::Template.
 
 POE is a relatively large system.  It includes internal classes that
 allow it to be customized without needing to know too much about the
@@ -346,8 +347,6 @@ POE::Loop::Select, POE::Loop::Tk
 
 POE::Pipe, POE::Pipe::OneWay, POE::Pipe::TwoWay
 
-POE::Preprocessor
-
 POE::Queue, POE::Queue::Array
 
 POE::Resource, POE::Resource::Aliases, POE::Resource::Events,
