@@ -1,4 +1,4 @@
-# $Id: IO_Poll.pm 2089 2006-09-02 05:53:27Z rcaputo $
+# $Id: IO_Poll.pm 2149 2006-11-03 02:45:24Z rcaputo $
 
 # IO::Poll event loop bridge for POE::Kernel.  The theory is that this
 # will be faster for large scale applications.  This file is
@@ -8,7 +8,7 @@
 package POE::Loop::IO_Poll;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 2089 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2149 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # Include common signal handling.
 use POE::Loop::PerlSignals;
@@ -304,9 +304,8 @@ sub loop_do_timeslice {
           next unless $got_mask;
 
           my $watch_mask = $poll_fd_masks{$fd};
-
           if ( $watch_mask & POLLRDNORM and
-               $got_mask & (POLLRDNORM | POLLHUP | POLLERR)
+               $got_mask & (POLLRDNORM | POLLHUP | POLLERR | POLLNVAL)
              ) {
             if (TRACE_FILES) {
               POE::Kernel::_warn "<fh> enqueuing read for fileno $fd";
@@ -316,7 +315,7 @@ sub loop_do_timeslice {
           }
 
           if ( $watch_mask & POLLWRNORM and
-               $got_mask & (POLLWRNORM | POLLHUP | POLLERR)
+               $got_mask & (POLLWRNORM | POLLHUP | POLLERR | POLLNVAL)
              ) {
             if (TRACE_FILES) {
               POE::Kernel::_warn "<fh> enqueuing write for fileno $fd";
@@ -326,7 +325,7 @@ sub loop_do_timeslice {
           }
 
           if ( $watch_mask & POLLRDBAND and
-               $got_mask & (POLLRDBAND | POLLHUP | POLLERR)
+               $got_mask & (POLLRDBAND | POLLHUP | POLLERR | POLLNVAL)
              ) {
             if (TRACE_FILES) {
               POE::Kernel::_warn "<fh> enqueuing expedite for fileno $fd";
