@@ -1,12 +1,12 @@
-# $Id: SIDs.pm,v 1.9 2004/01/21 05:28:15 rcaputo Exp $
+# $Id: SIDs.pm 2087 2006-09-01 10:24:43Z bsmith $
 
 # Session IDs: The data to maintain them, and accessors to get at them
 # sanely from other files.
 
-package POE::Resources::SIDs;
+package POE::Resource::SIDs;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.9 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 2087 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 # These methods are folded into POE::Kernel;
 package POE::Kernel;
@@ -89,7 +89,7 @@ __END__
 
 =head1 NAME
 
-POE::Resources::SIDs - session ID management for POE::Kernel
+POE::Resource::SIDs - session ID management for POE::Kernel
 
 =head1 SYNOPSIS
 
