@@ -1,5 +1,5 @@
 #!/usr/bin/perl -w
-# $Id: wheel_run.pm 2279 2008-03-09 21:53:28Z rcaputo $
+# $Id: wheel_run.pm 2127 2006-09-16 06:25:20Z rcaputo $
 
 use strict;
 use lib qw(./mylib ../mylib);
@@ -23,15 +23,9 @@ BEGIN {
     if ($@) {
       $error = "Win32::Console is required on $^O - try ActivePerl";
     }
-    elsif (exists $INC{"Tk.pm"}) {
-      $error = "$^O with Tk seems to hang on this test";
-    }
     elsif (exists $INC{"Event.pm"}) {
       $error = "$^O\'s fork() emulation breaks Event";
     }
-    else {
-      $error = "Signal handling on $^O is too fragile - Perl crashes";
-    }
 
     $RUNNING_WIN32 = 1;
   }
@@ -90,8 +84,10 @@ END
   $text =~ s/\n/ /g;
 
   my $os_quote = ($^O eq 'MSWin32') ? q(") : q(');
-  $chld_program_string  = [ $^X, "-we", "$text CORE::exit 0" ];
-  $chld_program_coderef = eval "sub { \$! = 1; " . $text . " }";
+  $chld_program_string = [ $^X, "-we", "$text CORE::exit 0" ];
+
+  $chld_program_coderef = eval
+    "sub { \$! = 1; " . $text . " }";
   die $@ if $@;
 }
 
@@ -118,7 +114,6 @@ my $shutdown_program = sub {
   else {
     print STDOUT "$out: got eof $flag";
   }
-  sleep 1;
 };
 # }}}
 
